"""
Entry point for running the web browser MCP server as a module.
This allows the server to be run with: python -m web_browser_mcp_server
"""

from . import main

if __name__ == "__main__":
    main()